==> CodeReview-0.1.1.tar.gz: CodeReview-0.1.1/CodeReview/Version.py <==
####################################################################################################
#
# CodeReview - A Python/Qt Git GUI
# Copyright (C) 2015 Fabrice Salvaire
#
# This program is free software: you can redistribute it and/or modify it under the terms of the GNU
# General Public License as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
# even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with this program.  If
# not, see <http://www.gnu.org/licenses/>.
#
####################################################################################################

####################################################################################################

# cf. http://en.wikipedia.org/wiki/Software_versioning

####################################################################################################

from CodeReview.Tools.RevisionVersion import RevisionVersion

####################################################################################################

pyqgit = RevisionVersion({'major':0,
                         'minor':1,
                         'revision':0,
                         'suffix':'',
                         })

####################################################################################################
#
# End
#
####################################################################################################

==> CodeReview-0.2.0.tar.gz: CodeReview-0.2.0/CodeReview/Version.py <==
####################################################################################################
#
# CodeReview - A Code Review GUI
# Copyright (C) 2015 Fabrice Salvaire
#
# This program is free software: you can redistribute it and/or modify it under the terms of the GNU
# General Public License as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
# even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with this program.  If
# not, see <http://www.gnu.org/licenses/>.
#
####################################################################################################

####################################################################################################

# cf. http://en.wikipedia.org/wiki/Software_versioning

####################################################################################################

from CodeReview.Tools.RevisionVersion import RevisionVersion

####################################################################################################

CodeReview = RevisionVersion({'major':0,
                              'minor':1,
                              'revision':0,
                              'suffix':'',
                             })

####################################################################################################
#
# End
#
####################################################################################################
